macro_rules! load_image {
($file_name:expr) => { ... };
}Expand description
Macro to load an image from the disk and automatically parse it depending on the provided magic constant.
macro_rules! load_image {
($file_name:expr) => { ... };
}Macro to load an image from the disk and automatically parse it depending on the provided magic constant.